/* Copyright 1999 VLSI Vision Ltd. Free for use under the Gnu Public License */



#ifdef __cplusplus
extern "C"
{
#endif

/* Initialisation Functions */
BOOL CPIA_CmdInit( int UnusedParameter );
void CPIA_CmdFini( void );

/* CPIA Functions */
BOOL CPIA_GetVersion( BYTE *FW_Version, BYTE *FW_Revision,
	 				  BYTE *VC_Version, BYTE *VC_Revision );

BOOL CPIA_GetPnPID( WORD *VendorID, WORD *ProductID, WORD *DeviceID );

BOOL CPIA_GetCameraStatus( BYTE *SystemState, BYTE *GrabState,
						   BYTE *StreamState, BYTE *FatalError,
						   BYTE *CmdError,    BYTE *DebugFlags,
						   BYTE *VPStatus,    BYTE *ErrorCode );

BOOL CPIA_GotoHiPower( void );
BOOL CPIA_GotoLoPower( void );
BOOL CPIA_GotoSuspend( void );
BOOL CPIA_GotoPassThrough( void );

BOOL CPIA_ModifyCameraStatus( BYTE StatusByte, BYTE AndMask, BYTE OrMask );


/* SYSTEM Functions */
BOOL CPIA_ReadVCRegs( BYTE Addr0, BYTE Addr1, BYTE Addr2, BYTE Addr3,
						BYTE *Reg0, BYTE *Reg1, BYTE *Reg2, BYTE *Reg3 );
BOOL CPIA_WriteVCReg( BYTE Addr, BYTE AndMask, BYTE OrMask );

BOOL CPIA_ReadMCPorts( BYTE *Port0, BYTE *Port1, BYTE *Port2, BYTE *Port3 );
BOOL CPIA_WriteMCPort( BYTE Port, BYTE AndMask, BYTE OrMask );

BOOL CPIA_SetBaudRate( DWORD BaudRate );
BOOL CPIA_SetECPTiming( BOOL SlowTiming );

BOOL CPIA_ReadIDATA( BYTE Addr0, BYTE Addr1, BYTE Addr2, BYTE Addr3,
						BYTE *Byte0, BYTE *Byte1, BYTE *Byte2, BYTE *Byte3 );

BOOL CPIA_WriteIDATA( BYTE Addr, BYTE AndMask, BYTE OrMask );

BOOL CPIA_GenericCall( WORD CallAddr );

BOOL CPIA_SerialStart( void );
BOOL CPIA_SerialStop( void );
BOOL CPIA_SerialWrite( BYTE WriteData );
BOOL CPIA_SerialRead( BOOL AckRead, BYTE *ReadData );


/* VP_CTRL Functions */
BOOL CPIA_GetVPVersion( BYTE *VP_Version, BYTE *VP_Revision,
  						BYTE *Sensor_Version, BYTE *Sensor_Revision );
BOOL CPIA_ResetFrameCounter( void );

BOOL CPIA_SetColourParams( BYTE Brightness, BYTE Contrast, BYTE Saturation );
BOOL CPIA_SetExposure( BYTE GainMode, BYTE ExpMode, BYTE CompMode, BYTE CentreWeight,
					   BYTE Gain, BYTE FineExp, BYTE CoarseExpLo, BYTE CoarseExpHi, 
					   BYTE RedComp, BYTE Green1Comp, BYTE Green2Comp, BYTE BlueComp );
BOOL CPIA_SetColourBalance( BYTE BalanceMode, BYTE RedGain,
							BYTE BlueGain, BYTE GreenGain );
BOOL CPIA_SetSensorFPS( BYTE SensorClkDivisor, BYTE BaseRate );

BOOL CPIA_SetVPDefaults( void );
BOOL CPIA_SetApcor( BYTE ApCorGain1, BYTE ApCorGain2, BYTE ApCorGain4, BYTE ApCorGain8 );
BOOL CPIA_FlickerCtrl( BYTE FlickerMode, BYTE CoarseJump, BYTE AllowableOverExposure);
BOOL CPIA_SetVLOffset( BYTE VLOffsetGain1, BYTE VLOffsetGain2, BYTE VLOffsetGain4, BYTE VLOffsetGain8 );

BOOL CPIA_GetColourParams( BYTE *Brightness, BYTE *Contrast, BYTE *Saturation );
BOOL CPIA_GetColourBalance( BYTE *RedGain, BYTE *GreenGain, BYTE *BlueGain );

BOOL CPIA_GetExposure( 	BYTE *Gain, BYTE *FineExp, BYTE *CoarseExpLo, BYTE *CoarseExpHi, 
					   		BYTE *RedComp, BYTE *Green1Comp, BYTE *Green2Comp, BYTE *BlueComp );
BOOL CPIA_SetSensorMatrix( BYTE Matrix[9] );
BOOL CPIA_ColourBars( BOOL EnableColourBars );

BOOL CPIA_ReadVPRegs( BYTE Addr0, BYTE Addr1, BYTE Addr2, BYTE Addr3,
						BYTE *Reg0, BYTE *Reg1, BYTE *Reg2, BYTE *Reg3 );
BOOL CPIA_WriteVPReg( BYTE Addr, BYTE AndMask, BYTE OrMask );


/* CAPTURE Functions */
BOOL CPIA_GrabFrame( byte InterruptLine );
BOOL CPIA_UploadFrame( byte ForceUpload );
BOOL CPIA_SetGrabMode( byte ContinuousGrab );

BOOL CPIA_InitStreamCap( byte SkipFrames, byte InterruptLine );
BOOL CPIA_FiniStreamCap( void );

BOOL CPIA_StartStreamCap( void );
BOOL CPIA_StopStreamCap( void );

BOOL CPIA_SetFormat(  BYTE VideoSize, BYTE SubSampling, BYTE YUVOrder );
BOOL CPIA_SetROI( BYTE ColStart, BYTE ColEnd, BYTE RowStart, BYTE RowEnd );
BOOL CPIA_SetCompression( BYTE CompMode, BYTE Decimation );
BOOL CPIA_SetCompressionTarget( BYTE FRTargetting, BYTE TargetFR, BYTE TargetQ );
BOOL CPIA_SetYUVThresh( BYTE YThresh, BYTE UVThresh );
BOOL CPIA_SetTargetFPS( BYTE TargetFPS );
BOOL CPIA_SetCompressionParams( BYTE Hysteresis, BYTE ThreshMax, BYTE SmallStep, BYTE LargeStep, 
								BYTE DecimationHysteresis, BYTE FRDiffStepThresh, BYTE QDiffStepThresh,
								BYTE DecimationThreshMod );
BOOL CPIA_DiscardFrame( void );
BOOL CPIA_GrabReset( void );


/* DEBUG Functions */
BOOL CPIA_OutputRS232( char String[8] );
BOOL CPIA_AbortProcess( void );
BOOL CPIA_SetDRAMPage( WORD StartPage, WORD EndPage );
BOOL CPIA_StartDRAMUpload( void );
BOOL CPIA_StartDummyStream( void );
BOOL CPIA_AbortStream( void );
BOOL CPIA_DownloadDRAM( WORD Packets, BYTE __huge *Buffer ); /* Packets is in terms of 8 byte packets */
BOOL CPIA_NullCmd( void );


/* function below just passes through to the CLINK layer 						*/
/* it remains purely to give compatiblity with earlier versions of CPIA_CMD 	*/
/* please don't use it for new applications. just call the CLINK layer directly */
BOOL CPIA_UploadStreamData( DWORD MaxBytes, byte __huge *Buffer, DWORD *ActualBytes, DWORD StreamChunkSize );


/* MACRO functions to access stream data */
BOOL CPIA_MACRO_TestStream( WORD StartPage, WORD EndPage, BYTE __huge *Buffer );
BOOL CPIA_MACRO_UploadDRAM( WORD StartPage, WORD EndPage, BYTE __huge *Buffer );
BOOL CPIA_MACRO_DownloadDRAM( WORD StartPage, WORD EndPage, BYTE __huge *Buffer );

#ifdef __cplusplus
}
#endif

